@@ -140,6 +140,7 @@ class Blaster():
         os.remove(self.temp_output)
         # print(self.inputfile)
         df = Blaster.resultdict2df(hsp_results)
+        # print(hsp_results)
         return df, hsp_results
 
     @staticmethod
@@ -232,45 +233,43 @@ class Blaster():
         print('Finish')
 
     @staticmethod
-    def get_nucl_seq(result_dict, out_path):
-        arg_records = []
+    def get_arg_seq(file_base, result_dict, out_path):
+        nucl_records = []
+        prot_records = []
+        prot_file = file_base + 'ARGs_prot.fasta'
+        nucl_file = file_base + 'ARGs_nucl.fasta'
+        prot_path = os.path.join(out_path, prot_file)
+        nucl_path = os.path.join(out_path, nucl_file)
         if len(result_dict.keys()) == 0:
             print('No ARGs were found...')
         else:
             for key in result_dict.keys():
                 hit_data = result_dict[key]
-                file = os.path.splitext(str(hit_data['FILE']))[0]
-                outfile = os.path.join(
-                    out_path, file + str('_ARGs_nucl.fasta'))
-                id = str(hit_data['SEQUENCE'] +
-                         '_' + hit_data['GENE']) + str('_' + hit_data['ACCESSION'])
-                name = str(hit_data['ACCESSION'])
-                record = SeqRecord(Seq(hit_data['QUERY_SEQ']),
-                                   id=id,
-                                   name=name,
-                                   description='')
-                arg_records.append(record)
-            SeqIO.write(arg_records, outfile, 'fasta')
+                # file = os.path.splitext(str(hit_data['FILE']))[0]
+                # outfile = os.path.join(
+                # out_path, file + str('_ARGs_nucl.fasta'))
+                nucl_sequence = Seq(str(hit_data['QUERY_SEQ']))
+                trim = len(nucl_sequence) % 3
+                if trim != 0:
+                    nucl_sequence = nucl_sequence + Seq('N' * (3 - trim))
+                prot_sequence = nucl_sequence.translate(
+                    table=11, to_stop=True)
 
-    @staticmethod
-    def get_prot_seq(result_dict, out_path):
-        arg_records = []
-        if len(result_dict.keys()) == 0:
-            print('No ARGs were found...')
-        else:
-            for key in result_dict.keys():
-                hit_data = result_dict[key]
-                file = os.path.splitext(str(hit_data['FILE']))[0]
-                outfile = os.path.join(
-                    out_path, file + str('_ARGs_prot.fasta'))
-                trim = len(Seq(hit_data['QUERY_SEQ'])) % 3
-                prot_seq = Seq(hit_data['QUERY_SEQ'][:-trim])
                 id = str(hit_data['SEQUENCE'] +
                          '_' + hit_data['GENE']) + str('_' + hit_data['ACCESSION'])
                 name = str(hit_data['ACCESSION'])
-                record = SeqRecord(prot_seq.translate(),
-                                   id=id,
-                                   name=name,
-                                   description='')
-                arg_records.append(record)
-            SeqIO.write(arg_records, outfile, 'fasta')
+
+                nucl_record = SeqRecord(nucl_sequence,
+                                        id=id,
+                                        name=name,
+                                        description='')
+                nucl_records.append(nucl_record)
+
+                prot_record = SeqRecord(prot_sequence,
+                                        id=id,
+                                        name=name,
+                                        description='')
+                prot_records.append(prot_record)
+
+            SeqIO.write(nucl_records, nucl_path, 'fasta')
+            SeqIO.write(prot_records, prot_path, 'fasta')
